@@ -15,16 +15,16 @@
 import copy
 import json
 import sys
+from unittest import mock
 
 import fixtures
-import mock
 import testtools
 
 from openstack_virtual_baremetal import build_nodes_json
 
 
 TEST_NODES = [{'arch': 'x86_64',
-               'capabilities': 'boot_option:local',
+               'capabilities': 'boot_option:local,boot_mode:bios',
                'cpu': 128,
                'disk': 1024,
                'mac': ['aa:aa:aa:aa:aa:aa'],
@@ -70,13 +70,11 @@ class TestBuildNodesJson(testtools.TestCase):
         args.env = None
         args.bmc_prefix = 'bmc-foo'
         args.baremetal_prefix = 'baremetal-foo'
-        args.provision_net = 'provision-foo'
         args.add_undercloud = False
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
+        bmc_base, baremetal_base, undercloud_name = (
             build_nodes_json._get_names(args))
         self.assertEqual('bmc-foo', bmc_base)
         self.assertEqual('baremetal-foo', baremetal_base)
-        self.assertEqual('provision-foo', provision_net)
         self.assertEqual('undercloud', undercloud_name)
 
     def test_get_names_no_env_w_undercloud(self):
@@ -84,37 +82,13 @@ class TestBuildNodesJson(testtools.TestCase):
         args.env = None
         args.bmc_prefix = 'bmc-foo'
         args.baremetal_prefix = 'baremetal-foo'
-        args.provision_net = 'provision-foo'
         args.add_undercloud = True
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
+        bmc_base, baremetal_base, undercloud_name = (
             build_nodes_json._get_names(args))
         self.assertEqual('bmc-foo', bmc_base)
         self.assertEqual('baremetal-foo', baremetal_base)
-        self.assertEqual('provision-foo', provision_net)
         self.assertEqual('undercloud', undercloud_name)
 
-    @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
-                create=True)
-    @mock.patch('yaml.safe_load')
-    def test_get_names_old_env(self, mock_load, mock_open):
-        args = mock.Mock()
-        args.env = 'foo.yaml'
-        args.add_undercloud = False
-        mock_env = {
-            'parameters': {
-                'bmc_prefix': 'bmc-foo',
-                'baremetal_prefix': 'baremetal-foo',
-                'provision_net': 'provision-foo'
-            },
-        }
-        mock_load.return_value = mock_env
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
-            build_nodes_json._get_names(args))
-        self.assertEqual('bmc-foo', bmc_base)
-        self.assertEqual('baremetal-foo', baremetal_base)
-        self.assertEqual('provision-foo', provision_net)
-        self.assertIsNone(undercloud_name)
-
     @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
                 create=True)
     @mock.patch('yaml.safe_load')
@@ -126,15 +100,13 @@ class TestBuildNodesJson(testtools.TestCase):
             'parameter_defaults': {
                 'bmc_prefix': 'bmc-foo',
                 'baremetal_prefix': 'baremetal-foo',
-                'provision_net': 'provision-foo'
             },
         }
         mock_load.return_value = mock_env
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
+        bmc_base, baremetal_base, undercloud_name = (
             build_nodes_json._get_names(args))
         self.assertEqual('bmc-foo', bmc_base)
         self.assertEqual('baremetal-foo', baremetal_base)
-        self.assertEqual('provision-foo', provision_net)
         self.assertIsNone(undercloud_name)
 
     @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
@@ -148,16 +120,14 @@ class TestBuildNodesJson(testtools.TestCase):
             'parameter_defaults': {
                 'bmc_prefix': 'bmc',
                 'baremetal_prefix': 'baremetal',
-                'provision_net': 'provision',
                 'role': 'foo',
             },
         }
         mock_load.return_value = mock_env
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
+        bmc_base, baremetal_base, undercloud_name = (
             build_nodes_json._get_names(args))
         self.assertEqual('bmc', bmc_base)
         self.assertEqual('baremetal', baremetal_base)
-        self.assertEqual('provision', provision_net)
         self.assertIsNone(undercloud_name)
 
     @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
@@ -171,16 +141,14 @@ class TestBuildNodesJson(testtools.TestCase):
             'parameter_defaults': {
                 'bmc_prefix': 'bmc-foo',
                 'baremetal_prefix': 'baremetal-foo-bar',
-                'provision_net': 'provision-foo',
                 'role': 'bar',
             },
         }
         mock_load.return_value = mock_env
-        bmc_base, baremetal_base, provision_net, undercloud_name = (
+        bmc_base, baremetal_base, undercloud_name = (
             build_nodes_json._get_names(args))
         self.assertEqual('bmc-foo', bmc_base)
         self.assertEqual('baremetal-foo', baremetal_base)
-        self.assertEqual('provision-foo', provision_net)
         self.assertIsNone(undercloud_name)
 
     @mock.patch('os_client_config.make_client')
@@ -203,21 +171,42 @@ class TestBuildNodesJson(testtools.TestCase):
 
     def test_get_ports(self):
         neutron = mock.Mock()
+        fake_fixed_ips = [{'subnet_id': 'provision_id'}]
         fake_ports = {
             'ports': [
-                {'name': 'random'},
-                {'name': 'bmc_1'},
-                {'name': 'bmc_0'},
-                {'name': 'baremetal_1'},
-                {'name': 'baremetal_0'},
+                {'name': 'random',
+                 'id': 'random_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'bmc_1',
+                 'id': 'bmc_1_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'bmc_0',
+                 'id': 'bmc_0_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'baremetal_1',
+                 'id': 'baremetal_1_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'baremetal_0',
+                 'id': 'baremetal_0_id',
+                 'fixed_ips': fake_fixed_ips},
+            ]
+        }
+        fake_subnets = {
+            'subnets': [
+                {'name': 'provision',
+                 'id': 'provision_id'}
             ]
         }
         neutron.list_ports.return_value = fake_ports
-        bmc_ports, bm_ports = build_nodes_json._get_ports(neutron, 'bmc',
-                                                          'baremetal')
-        self.assertEqual([{'name': 'bmc_0'}, {'name': 'bmc_1'}], bmc_ports)
-        self.assertEqual([{'name': 'baremetal_0'}, {'name': 'baremetal_1'}],
+        neutron.list_subnets.return_value = fake_subnets
+        bmc_ports, bm_ports, provision_net_map = build_nodes_json._get_ports(
+            neutron, 'bmc', 'baremetal')
+        self.assertEqual([fake_ports['ports'][2], fake_ports['ports'][1]],
+                         bmc_ports)
+        self.assertEqual([fake_ports['ports'][4], fake_ports['ports'][3]],
                          bm_ports)
+        self.assertEqual({'baremetal_0_id': 'provision',
+                          'baremetal_1_id': 'provision'}, provision_net_map)
 
     def test_get_ports_mismatch(self):
         neutron = mock.Mock()
@@ -228,40 +217,59 @@ class TestBuildNodesJson(testtools.TestCase):
 
     def test_get_ports_multiple(self):
         neutron = mock.Mock()
+        fake_fixed_ips = [{'subnet_id': 'provision_id'}]
         fake_ports = {
             'ports': [
-                {'name': 'random'},
-                {'name': 'bmc-foo_0'},
-                {'name': 'bmc-bar_0'},
-                {'name': 'baremetal-foo_0'},
-                {'name': 'baremetal-bar_0'},
+                {'name': 'random',
+                 'id': 'random_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'bmc-foo_0',
+                 'id': 'bmc_foo_0_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'bmc-bar_0',
+                 'id': 'bmc_bar_0_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'baremetal-foo_0',
+                 'id': 'baremetal_foo_0_id',
+                 'fixed_ips': fake_fixed_ips},
+                {'name': 'baremetal-bar_0',
+                 'id': 'baremetal_bar_0_id',
+                 'fixed_ips': fake_fixed_ips},
+            ]
+        }
+        fake_subnets = {
+            'subnets': [
+                {'name': 'provision',
+                 'id': 'provision_id'}
             ]
         }
         neutron.list_ports.return_value = fake_ports
-        bmc_ports, bm_ports = build_nodes_json._get_ports(neutron, 'bmc-foo',
-                                                          'baremetal-foo')
-        self.assertEqual([{'name': 'bmc-foo_0'}], bmc_ports)
-        self.assertEqual([{'name': 'baremetal-foo_0'}], bm_ports)
+        neutron.list_subnets.return_value = fake_subnets
+        bmc_ports, bm_ports, provision_net_map = build_nodes_json._get_ports(
+            neutron, 'bmc-foo', 'baremetal-foo')
+        self.assertEqual([fake_ports['ports'][1]], bmc_ports)
+        self.assertEqual([fake_ports['ports'][3]], bm_ports)
 
     def _fake_port(self, device_id, ip, mac):
         return {'device_id': device_id,
                 'fixed_ips': [{'ip_address': ip}],
                 }
 
-    def _create_build_nodes_mocks(self, nova, servers):
+    def _create_build_nodes_mocks(self, nova, servers,
+                                  provision_net='provision'):
         nova.servers.get.side_effect = servers
         servers[0].name = 'bm_0'
         servers[0].flavor = {'id': '1'}
-        servers[0].addresses = {'provision': [{'OS-EXT-IPS-MAC:mac_addr':
-                                               'aa:aa:aa:aa:aa:aa',
-                                               'addr': '2.1.1.1'}]}
+        servers[0].addresses = {provision_net: [
+            {'OS-EXT-IPS-MAC:mac_addr': 'aa:aa:aa:aa:aa:aa',
+             'addr': '2.1.1.1'}]}
         servers[0].image = {'id': 'f00'}
         servers[0].id = '123abc'
         servers[1].name = 'bm_1'
         servers[1].flavor = {'id': '1'}
-        servers[1].addresses = {'provision': [{'OS-EXT-IPS-MAC:mac_addr':
-                                               'aa:aa:aa:aa:aa:ab',
-                                               'addr': '2.1.1.2'}]}
+        servers[1].addresses = {provision_net: [
+            {'OS-EXT-IPS-MAC:mac_addr': 'aa:aa:aa:aa:aa:ab',
+             'addr': '2.1.1.2'}]}
         servers[1].image = {'id': 'f00'}
         servers[1].id = '456def'
         mock_flavor = mock.Mock()
@@ -272,11 +280,18 @@ class TestBuildNodesJson(testtools.TestCase):
 
     @mock.patch('os_client_config.make_client')
     def test_build_nodes(self, mock_make_client):
+        args = mock.Mock()
+        args.physical_network = False
+        args.driver = 'pxe_ipmitool'
+        args.id = False
         bmc_ports = [{'fixed_ips': [{'ip_address': '1.1.1.1'}]},
                      {'fixed_ips': [{'ip_address': '1.1.1.2'}]}
                      ]
-        bm_ports = [{'device_id': '1'}, {'device_id': '2'}]
-        physical_network = False
+        bm_ports = [{'device_id': '1', 'id': 'port_id_server1'},
+                    {'device_id': '2', 'id': 'port_id_server2'}]
+        provision_net_map = {'port_id_server1': 'provision',
+                             'port_id_server2': 'provision',
+                             'port_id_server3': 'provision', }
         nova = mock.Mock()
         servers = [mock.Mock(), mock.Mock(), mock.Mock()]
         self._create_build_nodes_mocks(nova, servers)
@@ -301,16 +316,13 @@ class TestBuildNodesJson(testtools.TestCase):
         glance = mock.Mock()
 
         (nodes,
-         bmc_bm_pairs,
          extra_nodes,
          network_details) = build_nodes_json._build_nodes(
-            nova, glance, bmc_ports, bm_ports, 'provision', 'bm', 'undercloud',
-            'pxe_ipmitool', physical_network)
+            nova, glance, bmc_ports, bm_ports, provision_net_map, 'bm',
+            'undercloud', args)
         expected_nodes = copy.deepcopy(TEST_NODES)
         expected_nodes[1]['disk'] = 100
         self.assertEqual(expected_nodes, nodes)
-        self.assertEqual([('1.1.1.1', 'bm_0'), ('1.1.1.2', 'bm_1')],
-                         bmc_bm_pairs)
         self.assertEqual(1, len(extra_nodes))
         self.assertEqual('undercloud', extra_nodes[0]['name'])
         self.assertEqual(
@@ -320,11 +332,18 @@ class TestBuildNodesJson(testtools.TestCase):
 
     @mock.patch('os_client_config.make_client')
     def test_build_nodes_with_driver(self, mock_make_client):
+        args = mock.Mock()
+        args.physical_network = False
+        args.driver = 'ipmi'
+        args.id = False
         bmc_ports = [{'fixed_ips': [{'ip_address': '1.1.1.1'}]},
                      {'fixed_ips': [{'ip_address': '1.1.1.2'}]}
                      ]
-        bm_ports = [{'device_id': '1'}, {'device_id': '2'}]
-        physical_network = False
+        bm_ports = [{'device_id': '1', 'id': 'port_id_server1'},
+                    {'device_id': '2', 'id': 'port_id_server2'}]
+        provision_net_map = {'port_id_server1': 'provision',
+                             'port_id_server2': 'provision',
+                             'port_id_server3': 'provision', }
         nova = mock.Mock()
         servers = [mock.Mock(), mock.Mock(), mock.Mock()]
         self._create_build_nodes_mocks(nova, servers)
@@ -349,18 +368,15 @@ class TestBuildNodesJson(testtools.TestCase):
         glance = mock.Mock()
 
         (nodes,
-         bmc_bm_pairs,
          extra_nodes,
          network_details) = build_nodes_json._build_nodes(
-            nova, glance, bmc_ports, bm_ports, 'provision', 'bm', 'undercloud',
-            'ipmi', physical_network)
+            nova, glance, bmc_ports, bm_ports, provision_net_map, 'bm',
+            'undercloud', args)
         expected_nodes = copy.deepcopy(TEST_NODES)
         expected_nodes[1]['disk'] = 100
         for node in expected_nodes:
             node['pm_type'] = 'ipmi'
         self.assertEqual(expected_nodes, nodes)
-        self.assertEqual([('1.1.1.1', 'bm_0'), ('1.1.1.2', 'bm_1')],
-                         bmc_bm_pairs)
         self.assertEqual(1, len(extra_nodes))
         self.assertEqual('undercloud', extra_nodes[0]['name'])
         self.assertEqual(
@@ -369,11 +385,19 @@ class TestBuildNodesJson(testtools.TestCase):
             '2.1.1.2', network_details['bm_1']['ips']['provision'][0]['addr'])
 
     def test_build_nodes_role_uefi(self):
+        args = mock.Mock()
+        args.physical_network = False
+        args.driver = 'pxe_ipmitool'
+        args.id = False
+
         bmc_ports = [{'fixed_ips': [{'ip_address': '1.1.1.1'}]},
                      {'fixed_ips': [{'ip_address': '1.1.1.2'}]}
                      ]
-        bm_ports = [{'device_id': '1'}, {'device_id': '2'}]
-        physical_network = False
+        bm_ports = [{'device_id': '1', 'id': 'port_id_server1'},
+                    {'device_id': '2', 'id': 'port_id_server2'}]
+        provision_net_map = {'port_id_server1': 'provision',
+                             'port_id_server2': 'provision',
+                             'port_id_server3': 'provision', }
         nova = mock.Mock()
         servers = [mock.Mock(), mock.Mock(), mock.Mock()]
         self._create_build_nodes_mocks(nova, servers)
@@ -387,9 +411,9 @@ class TestBuildNodesJson(testtools.TestCase):
         mock_image_get.get.return_value = 'uefi'
         glance.images.get.return_value = mock_image_get
 
-        nodes, bmc_bm_pairs, extra_nodes, _ = build_nodes_json._build_nodes(
-            nova, glance, bmc_ports, bm_ports, 'provision', 'bm-foo', None,
-            'pxe_ipmitool', physical_network)
+        nodes, extra_nodes, _ = build_nodes_json._build_nodes(
+            nova, glance, bmc_ports, bm_ports, provision_net_map, 'bm-foo',
+            None, args)
         expected_nodes = copy.deepcopy(TEST_NODES)
         expected_nodes[0]['name'] = 'bm-foo-control-0'
         expected_nodes[0]['capabilities'] = ('boot_option:local,'
@@ -400,9 +424,125 @@ class TestBuildNodesJson(testtools.TestCase):
                                              'boot_mode:uefi,'
                                              'profile:control')
         self.assertEqual(expected_nodes, nodes)
-        self.assertEqual([('1.1.1.1', 'bm-foo-control_0'),
-                          ('1.1.1.2', 'bm-foo-control_1')],
-                         bmc_bm_pairs)
+
+    @mock.patch('os_client_config.make_client')
+    def test_build_nodes_with_physnet(self, mock_make_client):
+        args = mock.Mock()
+        args.physical_network = True
+        args.driver = 'pxe_ipmitool'
+        args.id = False
+        bmc_ports = [{'fixed_ips': [{'ip_address': '1.1.1.1'}]},
+                     {'fixed_ips': [{'ip_address': '1.1.1.2'}]}
+                     ]
+        bm_ports = [{'device_id': '1', 'id': 'port_id_server1'},
+                    {'device_id': '2', 'id': 'port_id_server2'}]
+        provision_net_map = {'port_id_server1': 'provision',
+                             'port_id_server2': 'provision',
+                             'port_id_server3': 'provision', }
+        nova = mock.Mock()
+        servers = [mock.Mock(), mock.Mock(), mock.Mock()]
+        self._create_build_nodes_mocks(nova, servers)
+        servers[1].image = None
+        mock_to_dict = {'os-extended-volumes:volumes_attached':
+                        [{'id': 'v0lume'}]}
+        servers[1].to_dict.return_value = mock_to_dict
+        mock_cinder = mock.Mock()
+        mock_make_client.return_value = mock_cinder
+        mock_vol = mock.Mock()
+        mock_vol.size = 100
+        mock_cinder.volumes.get.return_value = mock_vol
+        servers[2].name = 'undercloud'
+        servers[2].flavor = {'id': '1'}
+        servers[2].addresses = {'provision': [{'OS-EXT-IPS-MAC:mac_addr':
+                                              'aa:aa:aa:aa:aa:ac'}]}
+        servers[2].image = {'id': 'f00'}
+        nova.servers.list.return_value = [servers[2]]
+        ips_return_val = 'ips call value'
+        nova.servers.ips.return_value = ips_return_val
+
+        glance = mock.Mock()
+
+        (nodes,
+         extra_nodes,
+         network_details) = build_nodes_json._build_nodes(
+            nova, glance, bmc_ports, bm_ports, provision_net_map, 'bm',
+            'undercloud', args)
+        expected_nodes = copy.deepcopy(TEST_NODES)
+        expected_nodes[1]['disk'] = 100
+        node0_mac = expected_nodes[0].pop('mac')
+        node1_mac = expected_nodes[1].pop('mac')
+        expected_nodes[0]['ports'] = [{'address': node0_mac[0],
+                                       'physical_network': 'provision'}]
+        expected_nodes[1]['ports'] = [{'address': node1_mac[0],
+                                       'physical_network': 'provision'}]
+        self.assertEqual(expected_nodes, nodes)
+        self.assertEqual(1, len(extra_nodes))
+        self.assertEqual('undercloud', extra_nodes[0]['name'])
+        self.assertEqual(
+            '2.1.1.1', network_details['bm_0']['ips']['provision'][0]['addr'])
+        self.assertEqual(
+            '2.1.1.2', network_details['bm_1']['ips']['provision'][0]['addr'])
+
+    @mock.patch('os_client_config.make_client')
+    def test_build_nodes_with_physnet_strip_id(self, mock_make_client):
+        args = mock.Mock()
+        args.physical_network = True
+        args.driver = 'pxe_ipmitool'
+        args.id = '123'
+        bmc_ports = [{'fixed_ips': [{'ip_address': '1.1.1.1'}]},
+                     {'fixed_ips': [{'ip_address': '1.1.1.2'}]}
+                     ]
+        bm_ports = [{'device_id': '1', 'id': 'port_id_server1'},
+                    {'device_id': '2', 'id': 'port_id_server2'}]
+        provision_net_map = {'port_id_server1': 'ctlplane-123',
+                             'port_id_server2': 'ctlplane-123',
+                             'port_id_server3': 'ctlplane-123', }
+        nova = mock.Mock()
+        servers = [mock.Mock(), mock.Mock(), mock.Mock()]
+        self._create_build_nodes_mocks(nova, servers,
+                                       provision_net='ctlplane-123')
+        servers[1].image = None
+        mock_to_dict = {'os-extended-volumes:volumes_attached':
+                        [{'id': 'v0lume'}]}
+        servers[1].to_dict.return_value = mock_to_dict
+        mock_cinder = mock.Mock()
+        mock_make_client.return_value = mock_cinder
+        mock_vol = mock.Mock()
+        mock_vol.size = 100
+        mock_cinder.volumes.get.return_value = mock_vol
+        servers[2].name = 'undercloud'
+        servers[2].flavor = {'id': '1'}
+        servers[2].addresses = {'ctlplane-123': [
+            {'OS-EXT-IPS-MAC:mac_addr': 'aa:aa:aa:aa:aa:ac'}]}
+        servers[2].image = {'id': 'f00'}
+        nova.servers.list.return_value = [servers[2]]
+        ips_return_val = 'ips call value'
+        nova.servers.ips.return_value = ips_return_val
+
+        glance = mock.Mock()
+
+        (nodes,
+         extra_nodes,
+         network_details) = build_nodes_json._build_nodes(
+            nova, glance, bmc_ports, bm_ports, provision_net_map, 'bm',
+            'undercloud', args)
+        expected_nodes = copy.deepcopy(TEST_NODES)
+        expected_nodes[1]['disk'] = 100
+        node0_mac = expected_nodes[0].pop('mac')
+        node1_mac = expected_nodes[1].pop('mac')
+        expected_nodes[0]['ports'] = [{'address': node0_mac[0],
+                                       'physical_network': 'ctlplane'}]
+        expected_nodes[1]['ports'] = [{'address': node1_mac[0],
+                                       'physical_network': 'ctlplane'}]
+        self.assertEqual(expected_nodes, nodes)
+        self.assertEqual(1, len(extra_nodes))
+        self.assertEqual('undercloud', extra_nodes[0]['name'])
+        self.assertEqual(
+            '2.1.1.1',
+            network_details['bm_0']['ips']['ctlplane-123'][0]['addr'])
+        self.assertEqual(
+            '2.1.1.2',
+            network_details['bm_1']['ips']['ctlplane-123'][0]['addr'])
 
     @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
                 create=True)
@@ -463,23 +603,6 @@ class TestBuildNodesJson(testtools.TestCase):
         f.write.assert_any_call(json.dumps({'nodes': [test_nodes[1]]},
                                            indent=2))
 
-    @mock.patch('openstack_virtual_baremetal.build_nodes_json.open',
-                create=True)
-    def test_write_pairs(self, mock_open):
-        pairs = [('1.1.1.1', 'bm_0'), ('1.1.1.2', 'bm_1')]
-        mock_open.return_value = mock.MagicMock()
-        build_nodes_json._write_pairs(pairs)
-        calls = [mock.call('# This file is DEPRECATED.  The mapping is now '
-                           'available in nodes.json.\n'),
-                 mock.call('# A list of BMC addresses and the name of the '
-                           'instance that BMC manages.\n'),
-                 mock.call('1.1.1.1 bm_0\n'),
-                 mock.call('1.1.1.2 bm_1\n'),
-                 ]
-        f = mock_open.return_value.__enter__.return_value
-        self.assertEqual(calls, f.write.mock_calls)
-
-    @mock.patch('openstack_virtual_baremetal.build_nodes_json._write_pairs')
     @mock.patch('openstack_virtual_baremetal.build_nodes_json.'
                 '_write_role_nodes')
     @mock.patch('openstack_virtual_baremetal.build_nodes_json._write_nodes')
@@ -490,14 +613,14 @@ class TestBuildNodesJson(testtools.TestCase):
     @mock.patch('openstack_virtual_baremetal.build_nodes_json._parse_args')
     def test_main(self, mock_parse_args, mock_get_names, mock_get_clients,
                   mock_get_ports, mock_build_nodes, mock_write_nodes,
-                  mock_write_role_nodes, mock_write_pairs):
+                  mock_write_role_nodes):
         args = mock.Mock()
         mock_parse_args.return_value = args
         bmc_base = mock.Mock()
         baremetal_base = mock.Mock()
-        provision_net = mock.Mock()
+        provision_net_map = mock.Mock()
         undercloud_name = 'undercloud'
-        mock_get_names.return_value = (bmc_base, baremetal_base, provision_net,
+        mock_get_names.return_value = (bmc_base, baremetal_base,
                                        undercloud_name)
         nova = mock.Mock()
         neutron = mock.Mock()
@@ -505,13 +628,11 @@ class TestBuildNodesJson(testtools.TestCase):
         mock_get_clients.return_value = (nova, neutron, glance)
         bmc_ports = mock.Mock()
         bm_ports = mock.Mock()
-        mock_get_ports.return_value = (bmc_ports, bm_ports)
+        mock_get_ports.return_value = (bmc_ports, bm_ports, provision_net_map)
         nodes = mock.Mock()
-        pairs = mock.Mock()
         extra_nodes = mock.Mock()
         network_details = mock.Mock()
-        mock_build_nodes.return_value = (nodes, pairs, extra_nodes,
-                                         network_details)
+        mock_build_nodes.return_value = (nodes, extra_nodes, network_details)
 
         build_nodes_json.main()
 
@@ -521,12 +642,10 @@ class TestBuildNodesJson(testtools.TestCase):
         mock_get_ports.assert_called_once_with(neutron, bmc_base,
                                                baremetal_base)
         mock_build_nodes.assert_called_once_with(nova, glance, bmc_ports,
-                                                 bm_ports, provision_net,
+                                                 bm_ports, provision_net_map,
                                                  baremetal_base,
                                                  undercloud_name,
-                                                 args.driver,
-                                                 args.physical_network)
+                                                 args)
         mock_write_nodes.assert_called_once_with(nodes, extra_nodes,
                                                  network_details, args)
         mock_write_role_nodes.assert_called_once_with(nodes, args)
-        mock_write_pairs.assert_called_once_with(pairs)
